###########################################################################

pid_path="$FS_PREFIX/tmp/run/widget_ext_crond.pid"
log_path="$FS_PREFIX/tmp/run/widget_ext_crond.log"

handlePid() {
  path="$1"
  if [ -f $path ]; then
    pid=$(cat $path)
    kill -9 $pid
  fi
  echo $$ >"$path"
}

openLog() {
  path="$1"
  size=0
  [ -f $path ] && \
      size=`stat -t $path | awk '{print $2}'`
  if [ "$size" -gt 20000 ]; then
    mv $path $path.old
    touch $path
  fi
}

log() {
  echo "$@" >>$log_path
}

log2() {
  prefix=$(date +"[%m.%d %H:%M:%S] ")
  echo "$prefix$@" >>$log_path
}

handlePid "$pid_path"
openLog "$log_path"

###########################################################################

log2 "Run crond: $@"

int_path=$FS_PREFIX/tmp/cron/interval
if [ ! -f $int_path ]; then
  log "Interval not specified, exit"
  rm -f $pid_path
  exit 0
fi

min=$(cat $int_path)
if [ "$min" = "" -o "$min" -le 0 ]; then
  log "Interval: $min, exit"
  rm -f $pid_path
  exit 0
fi

cron_file=$(find $FS_PREFIX/tmp/cron/crontabs -type f)
if [ ! -f "$cron_file" ]; then
  log "Crontab missing, exit"
  rm -f $pid_path
  exit 0
fi

weather_script=$(grep update_weather $cron_file | sed 's/.* //')
if [ ! -f "$weather_script" ]; then
  log "Weather script missing ($weather_script), exit"
  rm -f $pid_path
  exit 0
fi

let sec=min*60
log sec=$sec
log "Interval: $sec seconds"

while true; do
  sleep $sec

  log2 "Run sh $weather_script"
  sh $weather_script
done
