#!/bin/sh

log_path=$FS_PREFIX/tmp/run/widget_ext_weather.log
openLog() {
  path="$1"
  [ -f $path ] && size=`stat -t $path | awk '{print $2}'` || size=0
  [ "$size" -gt 20000 ] && mv $path $path.old
}
openLog $log_path
exec >>$log_path 2>&1

BASEDIR=$(dirname "$(dirname "$(readlink -f "$0")")"); STORE_IFS=$IFS; IFS='/' path_array=($BASEDIR); IFS=$STORE_IFS; n=${#path_array[@]}
PLUGIN_NAME="${path_array[$n-1]}"
if [ -d /persistfs/plugins_data/$PLUGIN_NAME ]; then              
    DATA_DIR="/persistfs/plugins_data/$PLUGIN_NAME"
elif [ -d $FS_PREFIX/flashdata/plugins_data/$PLUGIN_NAME ]; then            
    DATA_DIR="$FS_PREFIX/flashdata/plugins_data/$PLUGIN_NAME"
else                          
    DATA_DIR=
fi

apiKey=""
if [ -f $DATA_DIR/settings.properties ]; then
    exec <"$DATA_DIR/settings.properties"
    while true; do
        read key op value
        [ "$key" = "" ] && break
        [ "$key" = "apiKey" ] && apiKey="$value"
    done
fi

if [ "$apiKey" = "" ]; then
    echo "API key is missing"
    exit
fi

###########################################################################

LOCK_FILE="$FS_PREFIX/tmp/run/widget.lock"
WEATHER_FILE="$FS_PREFIX/tmp/weather.txt"
LOCATION_INFO_FILE="$FS_PREFIX/tmp/location_info.properties"
PERSISTENT_LOCATION_INFO_FILE="$FS_PREFIX/config/location_info.properties"

###########################################################################

(set -C; echo $$ >"$LOCK_FILE") 2>/dev/null || exit
trap "rm -f $LOCK_FILE" 0 2 15

widget_country=""
widget_city=""

if [ -f $FS_PREFIX/config/settings.properties ]; then
    exec <"$FS_PREFIX/config/settings.properties"
    while true; do
        read key op value
        [ "$key" = "" ] && break
        [ "$key" = "widget_country" ] && widget_country="$value"
        [ "$key" = "widget_city" ] && widget_city="$value"
    done
fi

#echo "Updating weather data..."
if [ -f /etc/TZ ]; then
    TZ=`cat /etc/TZ`; export TZ; date +"%d.%m.%Y %T"
else
    date +"%d.%m.%Y %T"
fi
#echo "Retrieving location info..."
###########################################################################

#echo "City (settings): $widget_city"
#echo "Country (settings): $widget_country"

p_city="$widget_city"
p_country="$widget_country"
if [ "$p_city" = "" -o "$p_country" = "" ]; then
    sh $FS_PREFIX/firmware/scripts/run_get_location_info.sh
    p_location_info_file=""
    if [ -f "$LOCATION_INFO_FILE" ]; then
        p_location_info_file="$LOCATION_INFO_FILE"
    elif [ -f "$PERSISTENT_LOCATION_INFO_FILE" ]; then
        p_location_info_file="$PERSISTENT_LOCATION_INFO_FILE"
    fi

    if [ "$p_location_info_file" != "" ]; then
        loaded_city=""
        loaded_country=""

#        echo "Loading location info from ${p_location_info_file}..."

        exec <"$p_location_info_file"
        while true; do
            read key op value
            [ "$key" = "" ] && break
            [ "$key" = "city" ] && loaded_city="$value"
            [ "$key" = "country" ] && loaded_country="$value"
        done

 #       echo "City (loaded): $loaded_city"
 #       echo "Country (loaded): $loaded_country"

        [ "$p_city" = "" ] && p_city="$loaded_city"
        [ "$p_country" = "" ] && p_country="$loaded_country"
    fi
fi

if [ "$p_city" = "" -a "$p_country" = "" ]; then
    echo "Failed to get location info"
    exit
fi

echo "City: $p_city, Country: $p_country"

###########################################################################

#echo "Retrieving weather info..."

if [ "$p_city" == "" ]; then
    p_location="$p_country"
    p_location_caption="$p_country"
elif [ "$p_country" == "" ]; then
    p_location="$p_city"
    p_location_caption="$p_city"
else
    p_location="$p_city,$p_country"
    p_location_caption="$p_city"
fi
#echo "Location: $p_location"
#echo "Location caption: $p_location_caption"

p_location=`echo "$p_location" | sed 's/ /%20/g'`

url="http://api.openweathermap.org/data/2.5/weather?q=${p_location}&mode=xml&units=metric&APPID=${apiKey}"

echo "Requesting URL: $url"

tmp="$FS_PREFIX/tmp/weather_tmp.txt"
d_cond_icon_id=""
d_temp=""
if wget -O "$tmp" "$url"; then
    d_temp=`cat $tmp | grep '<temperature' | sed 's/^.*<temperature[^<>]*value="\([^"]*\).*$/\1/' | awk '{printf("%1.0f", $1)}'`
    d_cond_icon_id=`cat $tmp | grep '<weather' | sed 's/^.*<weather[^<>]*icon="\([0-9]*\).*$/\1/'`
fi

#echo "Retrieved weather info:"
#echo "-----"
#cat "$tmp"
#echo
#echo "-----"

rm -f "$tmp"

#echo "d_cond_icon_id = '$d_cond_icon_id'"
#echo "d_temp = '$d_temp'"

if [ "$d_cond_icon_id" = "" -o "$d_temp" = "" ]; then
    echo "Failed to retrieve weather info"
    exit
fi

get_weather_type() {
    case "$1" in
        01)
            echo "clear"
            ;;
        02)
            echo "clear_clouds"
            ;;
        03)
            echo "clouds"
            ;;
        04)
            echo "heavy_clouds"
            ;;
        09)
            echo "heavy_rain"
            ;;
        10)
            echo "rain"
            ;;
        11)
            echo "thunderstorm"
            ;;
        13)
            echo "snow"
            ;;
        50)
            echo "clear_clouds"
            ;;
        *)
            echo "unknown"
            ;;
    esac
}

res_type=`get_weather_type $d_cond_icon_id`
res_temp="${d_temp}C"
[ "$d_temp" -ge 0 ] && res_temp="+$res_temp"

###########################################################################

echo "$res_temp $res_type $p_location_caption" >"$WEATHER_FILE.tmp"
mv -f "$WEATHER_FILE.tmp" "$WEATHER_FILE"

#echo "Resulting weather info:"
#echo "-----"
cat "$WEATHER_FILE"
#echo "-----"

#echo "Weather data updated"
#date
