#!/bin/sh

log_path=$FS_PREFIX/tmp/run/widget_ext_weather.log
openLog() {
  path="$1"
  [ -f $path ] && size=`stat -t $path | awk '{print $2}'` || size=0
  [ "$size" -gt 20000 ] && mv $path $path.old
}
openLog $log_path
exec >>$log_path 2>&1

ilang=$(grep 'interface_language =' $FS_PREFIX/config/settings.properties | tail -n1 | sed 's/.* = //')

BASEDIR=$(dirname "$(dirname "$(readlink -f "$0")")"); STORE_IFS=$IFS; IFS='/' path_array=($BASEDIR); IFS=$STORE_IFS; n=${#path_array[@]}
PLUGIN_NAME="${path_array[$n-1]}"
if [ -d /persistfs/plugins_data/$PLUGIN_NAME ]; then              
    DATA_DIR="/persistfs/plugins_data/$PLUGIN_NAME"
elif [ -d $FS_PREFIX/flashdata/plugins_data/$PLUGIN_NAME ]; then            
    DATA_DIR="$FS_PREFIX/flashdata/plugins_data/$PLUGIN_NAME"
else                          
    DATA_DIR=
fi
cityId=0
if [ -f $DATA_DIR/settings.properties ]; then
    exec <"$DATA_DIR/settings.properties"
    while true; do
        read key op value
        [ "$key" = "" ] && break
        [ "$key" = "yandex_cityId" ] && cityId="$value"
    done
fi
if [ "$cityId" = "" ]; then
    cityId=0
fi
if [ -f /etc/TZ ]; then
    TZ=`cat /etc/TZ`; export TZ; date +"%d.%m.%Y %T"
else
    date +"%d.%m.%Y %T"
fi
url="http://api.weather.yandex.ru/v1/forecast/?geoid="$cityId
echo "CityID: $cityId"
echo "Requesting URL: $url"
tmp="$FS_PREFIX/tmp/weather_tmp.txt"
d_cond=""
d_temp=""
d_city=""
if wget --header="X-Yandex-Weather-Client: YandexWeatherAndroid/4.09" --header="X-Yandex-Weather-Token: 36d8b20e1787bad341cadee08796c136" --header="X-Yandex-Weather-Timestamp: 1458746640" -t 1 -O "$tmp" "$url"; then
    citydata=`cat $tmp | grep -o ',"geo_object":{.*},"fact":' | sed 's/\(,"geo_object":{\|},"fact":\)//g' | grep -o ',"locality":{.*},"province":' | sed 's/\(,"locality":{\|},"province":\)//g'`
    d_city=`echo $citydata | awk '{n=split($0,a,","); for (i=1; i<=n; i++) { split(a[i],b,":"); if (b[1] == "\"name\"") { print b[2]; return; } } }'`
    temp_len=`expr length "$d_city"`
    temp_end=$(($temp_len-1))
    d_city=`echo $d_city | cut -c 2-$temp_end`
    factdata=`cat $tmp | tr "\n" "|" | grep -o ',"fact":{.*},"forecasts":' | sed 's/\(,"fact":{\|},"forecasts":\)//g' | sed 's/|/\n/g'`
    d_temp=`echo $factdata | awk '{n=split($0,a,","); for (i=1; i<=n; i++) { split(a[i],b,":"); if (b[1] == "\"temp\"") { print b[2]; return; } } }'`
    d_cond=`echo $factdata | awk '{n=split($0,a,","); for (i=1; i<=n; i++) { split(a[i],b,":"); if (b[1] == "\"condition\"") { print b[2]; return; } } }'`
    temp_len=`expr length "$d_cond"`
    temp_end=$(($temp_len-1))
    d_cond=`echo $d_cond | cut -c 2-$temp_end`
    echo "XML loaded: city="$d_city"; temp="$d_temp"; cond="$d_cond
fi
rm -f "$tmp"
if [ "$d_cond" = "" -o "$d_temp" = "" -o "$d_city" = "" ]; then
    echo "Failed to retrieve weather info"
    exit
fi

get_weather_type() {
    case "$1" in
        "clear") echo "clear" ;;
        "partly-cloudy") echo "clear_clouds" ;;
        "cloudy"|"overcast") echo "clouds" ;;
        "overcast-and-light-rain"|"cloudy-and-rain") echo "rain" ;;
        "heavy-rain") echo "heavy_rain" ;;
        "thunderstorm"|"overcast-thunderstorms-with-rain") echo "thunderstorm" ;;
        "snow"|"cloudy-and-snow"|"overcast-and-light-snow") echo "snow" ;;
        *) echo "unknown" ;;
    esac
}

res_type=`get_weather_type "$d_cond"`
temp_sign=`echo $d_temp | cut -c -1`
temp_value="0"
if [ "$temp_sign" = "-" ]; then
    temp_sign="-"
    temp_value=`echo $d_temp | cut -c 2-`
elif [ "$temp_sign" = "+" ]; then
    temp_sign="+"
    temp_value=`echo $d_temp | cut -c 2-`
else
    temp_sign="+"
    temp_value=$d_temp
fi
res_temp=$temp_sign$temp_value"C"

###########################################################################
WEATHER_FILE="$FS_PREFIX/tmp/weather.txt"

if [ "$addInfoType" = "weekDay" ]; then
  inf=$(date +"%a")
  [ "$ilang" = "russian" -o "$ilang" = "ukrainian" ] && \
    inf=$(echo "$inf" | sed "s/Mon/Понедельник/g; s/Tue/Вторник/g; s/Wed/Среда/g; s/Thu/Четверг/g; s/Fri/Пятница/g; s/Sat/Суббота/g; s/Sun/Воскресенье/g")
else
  d_city=$(echo "$d_city" | cut -d',' -f 1)
  lenght=${#d_city}
  if [ "$lenght" -lt 17 ]; then
    let "ext_lenght=17-$lenght"
    A=$(printf "%.${ext_lenght}d" 0 | sed "s/0/  /g")
    inf=$d_city$A
  else
    inf=${d_city:0:17}
  fi
fi

echo "$res_temp $res_type $d_city" >"$WEATHER_FILE.tmp"

mv -f "$WEATHER_FILE.tmp" "$WEATHER_FILE"

cat "$WEATHER_FILE""
